import request from "@/utils/request";
import {AxiosPromise} from "axios";
import {AddressId, Area, AreaCard, AreaLineData, AreaParams} from "@/api/areaboard/types";
import {DashboardData} from "@/api/dashboard/types";
import {SchoolList} from "@/api/school/types";

/**
 * 获取区域
 */
export function getAreaAddress(id: number): AxiosPromise<Area[]> {
  return request({
    url: "/board/v1/area",
    method: "get",
    params: {parent_id: id},
  });
}

/**
 * 获取学校
 * /board/v1/get-school?province_id=&city_id=
 */
export function getAreaSchool(province_id: number, city_id: number): AxiosPromise<SchoolList[]> {
  return request({
    url: "/board/v1/get-school",
    method: "get",
    params: {province_id: province_id, city_id: city_id},
  });
}

/**
 * 获取区域级数据卡片
 * /board/v1/record-top?start_time=1672502400&end_time=1688349643&school_id=95&grade_id=35
 */
export function getAreaCard(params: AreaParams): AxiosPromise<AreaCard> {
  return request({
    url: "/board/v1/record-top",
    method: "get",
    params: params,
  });
}
/**
 * 获取区域级饼图
 * /board/v1/record?start_time=1672502400&end_time=1688349643&school_id=95&grade_id=35
 */
export function getAreaBoardPies(params: AreaParams): AxiosPromise<DashboardData> {
  return request({
    url: "/board/v1/record",
    method: "get",
    params: params,
  });
}
/**
 * 获取区域级折线图
 * /board/v1/record-bottom?start_time=1672502400&end_time=1688349643&school_id=95&grade_id=35
 */
export function getAreaBoardLines(params: AreaParams): AxiosPromise<AreaLineData> {
  return request({
    url: "/board/v1/record-bottom",
    method: "get",
    params: params,
  });
}
