import {TeacherItem} from "@/api/teacher/types";

/**
 * 获取训练记录参数
 * ?school_id=95&is_formal=1&search=略&grade_id=35&page=1&page_size=10
 */
export interface TrainingParams {
  school_id: number;
  grade_id: number;
  // 1正式，2非正式
  is_formal: number;
  // 学生名称/手机号
  search: string;
  page: number;
  page_size: number;
}

/**
 * 训练记录列表
 */
export interface TrainingItem {
  name: string;
  phone: string;
  // 0：放松，其他：专注
  device_id: number;
  device_name: string;
  create_time: string;
  play_time: string;
  grade_name: string;
  game_record_id: string;
  // 报告状态：1正常
  report_status: number;
}

export interface TrainingManage {
  lists: TrainingItem[];
  // 数量
  count: number;
}

export interface TrainingResult {
  name: string;
  phone: string;
  minute: number; //分
  second: number; //秒
  device_name: string; //训练场景
  create_time: string; //训练时间
  height_value: number; //高专注力占比
  att_average: number; //平均专注力
  scope_diff: number; //专注力维持区间
  interfere: number; //受干扰次数
  radar: number[][]; //雷达图
  line: number[]; //脑电曲线图1
  line_med: number[]; //脑电曲线图2
  amp: number[]; //脑电曲线图3
  percentage: number[]; //专注力分布饼图
  mean_content: {
    //专注力平均值描述和星星数
    star: number;
    content: string;
  };
  height_content: {
    //高专注占比描述
    star: number;
    content: string;
  };
  stable_content: {
    //稳定度描述
    star: number;
    content: string;
  };
  awaken_content: {
    //唤醒效率描述
    star: number;
    content: string;
  };
  linemed_content: {
    //整体和谐度
    star: number;
    content: string;
  };
  minDescription: string[]; //大脑小贴士
  height_med: number; //深度放松占比
  average_med: number; //平均放松度
  high_linemed: number; //最高放松度
  scope_med: number; //放松度维持区间
  stable_med: number; //放松度稳定度
  average_content: {
    //放松度平均值描述和星星
    star: number;
    content: string;
  };
  height_med_content: {
    //深度放松占比描述
    star: number;
    content: string;
  };
  stable_med_content: {
    //放松度稳定度描述
    star: number;
    content: string;
  };
}
