import {createRouter, createWebHashHistory, RouteRecordRaw} from "vue-router";

export const Layout = () => import("@/layout/school.vue");

// 静态路由
export const constantRoutes: RouteRecordRaw[] = [
  {
    path: "/:pathMatch(.*)*", // 解决路由爆[Vue Router warn]: No match found for location with path
    meta: {title: "找不到此页面", hidden: true},
    component: () => import("@/views/error/404.vue"),
  },
  {
    path: "/redirect",
    component: Layout,
    meta: {hidden: true},
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/login/redirect.vue"),
      },
    ],
  },
  {
    path: "/login",
    component: () => import("@/views/login/index.vue"),
    meta: {title: "登录", hidden: true},
  },
];

/**
 * 创建路由
 */
const router = createRouter({
  history: createWebHashHistory(),
  routes: constantRoutes as RouteRecordRaw[],
  // 刷新时，滚动条位置还原
  scrollBehavior: () => ({left: 0, top: 0}),
});

/**
 * 重置路由
 */
export function resetRouter() {
  router.replace({path: "/login"});
}

export default router;
